changeset 2823:165d390cbdaa

Automated merge with ssh://hg.atheme-project.org//hg//audacious-plugins
author Calin Crisan ccrisan@gmail.com
date Sun, 13 Jul 2008 20:18:19 +0300
parents 6a31fa1c2803 (diff) e883536cefe0 (current diff)
children 9cdd04a31ab2 eb4cacfc1d03
files
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/madplug/plugin.c	Sun Jul 13 20:18:00 2008 +0300
+++ b/src/madplug/plugin.c	Sun Jul 13 20:18:19 2008 +0300
@@ -488,8 +488,8 @@
             }
             break;
         }
-    } while (state != STATE_FATAL && tries < 16);
-    /* Give up after 16 failed resync attempts or fatal errors */
+    } while (state != STATE_FATAL && tries < 256);
+    /* Give up after 256 failed resync attempts or fatal errors */
 
     g_message("Rejecting %s (not an MP3 file?)", filename);
     return 0;